@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2011 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2012 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -92,9 +92,6 @@ static Image *ReadHALDImage(const ImageInfo *image_info,
   Image
     *image;
 
-  ssize_t
-    y;
-
   MagickBooleanType
     status;
 
@@ -102,6 +99,9 @@ static Image *ReadHALDImage(const ImageInfo *image_info,
     cube_size,
     level;
 
+  ssize_t
+    y;
+
   /*
     Create HALD color lookup table image.
   */
@@ -122,6 +122,9 @@ static Image *ReadHALDImage(const ImageInfo *image_info,
   cube_size=level*level;
   image->columns=(size_t) (level*cube_size);
   image->rows=(size_t) (level*cube_size);
+#if defined(MAGICKCORE_OPENMP_SUPPORT)
+  #pragma omp parallel for schedule(static,8) shared(status)
+#endif
   for (y=0; y < (ssize_t) image->rows; y+=(ssize_t) level)
   {
     ssize_t
@@ -146,10 +149,10 @@ static Image *ReadHALDImage(const ImageInfo *image_info,
     {
       for (red=0; red < (ssize_t) cube_size; red++)
       {
-        q->red=ClampToQuantum(QuantumRange*red/(cube_size-1.0));
-        q->green=ClampToQuantum(QuantumRange*green/(cube_size-1.0));
-        q->blue=ClampToQuantum(QuantumRange*blue/(cube_size-1.0));
-        SetOpacityPixelComponent(q,OpaqueOpacity);
+        SetPixelRed(q,ClampToQuantum(QuantumRange*red/(cube_size-1.0)));
+        SetPixelGreen(q,ClampToQuantum(QuantumRange*green/(cube_size-1.0)));
+        SetPixelBlue(q,ClampToQuantum(QuantumRange*blue/(cube_size-1.0)));
+        SetPixelOpacity(q,OpaqueOpacity);
         q++;
       }
     }
