@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2011 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2012 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -44,6 +44,7 @@
 #include "magick/blob-private.h"
 #include "magick/cache.h"
 #include "magick/colorspace.h"
+#include "magick/colorspace-private.h"
 #include "magick/exception.h"
 #include "magick/exception-private.h"
 #include "magick/image.h"
@@ -300,7 +301,7 @@ static MagickBooleanType WriteHRZImage(const ImageInfo *image_info,Image *image)
     &image->exception);
   if (hrz_image == (Image *) NULL)
     return(MagickFalse);
-  if (hrz_image->colorspace != RGBColorspace)
+  if (IsRGBColorspace(hrz_image->colorspace) == MagickFalse)
     (void) TransformImageColorspace(hrz_image,RGBColorspace);
   /*
     Allocate memory for pixels.
