@@ -156,10 +156,12 @@ static const CoderMapInfo
     { "MP4", "MPEG" },
     { "MPG", "MPEG" },
     { "MPRI", "MPR" },
+    { "MEF", "DNG" },
     { "MRW", "DNG" },
     { "MSVG", "SVG" },
     { "NEF", "DNG" },
     { "NETSCAPE", "MAGICK" },
+    { "NRW", "DNG" },
     { "O", "RAW" },
     { "ORF", "DNG" },
     { "OTF", "TTF" },
