@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2011 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2012 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -39,7 +39,9 @@ typedef enum
   ResetAlphaChannel,  /* deprecated */
   SetAlphaChannel,
   ShapeAlphaChannel,
-  TransparentAlphaChannel
+  TransparentAlphaChannel,
+  FlattenAlphaChannel,
+  RemoveAlphaChannel
 } AlphaChannelType;
 
 typedef enum
@@ -134,6 +136,7 @@ typedef struct _ChromaticityInfo
 #include "magick/effect.h"
 #include "magick/geometry.h"
 #include "magick/layer.h"
+#include "magick/locale_.h"
 #include "magick/monitor.h"
 #include "magick/pixel.h"
 #include "magick/profile.h"
@@ -336,8 +339,10 @@ struct _Image
 
   MagickBooleanType
     ping;
-};
 
+  size_t
+    channels;
+};
 
 struct _ImageInfo
 {
@@ -529,6 +534,7 @@ extern MagickExport MagickBooleanType
   SetImageInfo(ImageInfo *,const unsigned int,ExceptionInfo *),
   SetImageMask(Image *,const Image *),
   SetImageOpacity(Image *,const Quantum),
+  SetImageChannels(Image *,const size_t),
   SetImageStorageClass(Image *,const ClassType),
   SetImageType(Image *,const ImageType),
   StripImage(Image *),
@@ -542,6 +548,9 @@ extern MagickExport size_t
 extern MagickExport ssize_t
   GetImageReferenceCount(Image *);
 
+extern MagickExport size_t
+  GetImageChannels(Image *);
+
 extern MagickExport VirtualPixelMethod
   GetImageVirtualPixelMethod(const Image *),
   SetImageVirtualPixelMethod(const Image *,const VirtualPixelMethod);
