@@ -17,7 +17,7 @@
 %                                 July 1998                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2011 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2012 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -174,6 +174,8 @@ MagickExport MagickBooleanType FloodfillPaintImage(Image *image,
     return(MagickFalse);
   if (SetImageStorageClass(image,DirectClass) == MagickFalse)
     return(MagickFalse);
+  if ((target->opacity != OpaqueOpacity) && (image->matte == MagickFalse))
+    (void) SetImageAlphaChannel(image,OpaqueAlphaChannel);
   if (image->matte == MagickFalse)
     (void) SetImageAlphaChannel(image,OpaqueAlphaChannel);
   /*
@@ -341,23 +343,23 @@ MagickExport MagickBooleanType FloodfillPaintImage(Image *image,
     indexes=GetCacheViewAuthenticIndexQueue(image_view);
     for (x=0; x < (ssize_t) image->columns; x++)
     {
-      if (p->opacity != OpaqueOpacity)
+      if (GetPixelOpacity(p) != OpaqueOpacity)
         {
           (void) GetFillColor(draw_info,x,y,&fill_color);
           SetMagickPixelPacket(image,&fill_color,(IndexPacket *) NULL,&fill);
           if (image->colorspace == CMYKColorspace)
             ConvertRGBToCMYK(&fill);
           if ((channel & RedChannel) != 0)
-            q->red=ClampToQuantum(fill.red);
+            SetPixelRed(q,ClampToQuantum(fill.red));
           if ((channel & GreenChannel) != 0)
-            q->green=ClampToQuantum(fill.green);
+            SetPixelGreen(q,ClampToQuantum(fill.green));
           if ((channel & BlueChannel) != 0)
-            q->blue=ClampToQuantum(fill.blue);
+            SetPixelBlue(q,ClampToQuantum(fill.blue));
           if ((channel & OpacityChannel) != 0)
-            q->opacity=ClampToQuantum(fill.opacity);
+            SetPixelOpacity(q,ClampToQuantum(fill.opacity));
           if (((channel & IndexChannel) != 0) &&
               (image->colorspace == CMYKColorspace))
-            indexes[x]=ClampToQuantum(fill.index);
+            SetPixelIndex(indexes+x,ClampToQuantum(fill.index));
         }
       p++;
       q++;
@@ -614,7 +616,7 @@ MagickExport Image *OilPaintImage(const Image *image,const double radius,
   image_view=AcquireCacheView(image);
   paint_view=AcquireCacheView(paint_image);
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp parallel for schedule(dynamic,4) shared(progress,status)
+  #pragma omp parallel for schedule(static,4) shared(progress,status)
 #endif
   for (y=0; y < (ssize_t) image->rows; y++)
   {
@@ -687,7 +689,8 @@ MagickExport Image *OilPaintImage(const Image *image,const double radius,
       }
       *q=(*(p+j));
       if (image->colorspace == CMYKColorspace)
-        paint_indexes[x]=indexes[x+j];
+        SetPixelIndex(paint_indexes+x,GetPixelIndex(
+          indexes+x+j));
       p++;
       q++;
     }
@@ -761,7 +764,7 @@ MagickExport MagickBooleanType OpaquePaintImage(Image *image,
   const MagickPixelPacket *target,const MagickPixelPacket *fill,
   const MagickBooleanType invert)
 {
-  return(OpaquePaintImageChannel(image,AllChannels,target,fill,invert));
+  return(OpaquePaintImageChannel(image,CompositeChannels,target,fill,invert));
 }
 
 MagickExport MagickBooleanType OpaquePaintImageChannel(Image *image,
@@ -796,6 +799,8 @@ MagickExport MagickBooleanType OpaquePaintImageChannel(Image *image,
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   if (SetImageStorageClass(image,DirectClass) == MagickFalse)
     return(MagickFalse);
+  if ((fill->opacity != OpaqueOpacity) && (image->matte == MagickFalse))
+    (void) SetImageAlphaChannel(image,OpaqueAlphaChannel);
   /*
     Make image color opaque.
   */
@@ -805,7 +810,7 @@ MagickExport MagickBooleanType OpaquePaintImageChannel(Image *image,
   GetMagickPixelPacket(image,&zero);
   image_view=AcquireCacheView(image);
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp parallel for schedule(dynamic,4) shared(progress,status)
+  #pragma omp parallel for schedule(static,4) shared(progress,status)
 #endif
   for (y=0; y < (ssize_t) image->rows; y++)
   {
@@ -837,16 +842,16 @@ MagickExport MagickBooleanType OpaquePaintImageChannel(Image *image,
       if (IsMagickColorSimilar(&pixel,target) != invert)
         {
           if ((channel & RedChannel) != 0)
-            q->red=ClampToQuantum(fill->red);
+            SetPixelRed(q,ClampToQuantum(fill->red));
           if ((channel & GreenChannel) != 0)
-            q->green=ClampToQuantum(fill->green);
+            SetPixelGreen(q,ClampToQuantum(fill->green));
           if ((channel & BlueChannel) != 0)
-            q->blue=ClampToQuantum(fill->blue);
+            SetPixelBlue(q,ClampToQuantum(fill->blue));
           if ((channel & OpacityChannel) != 0)
-            q->opacity=ClampToQuantum(fill->opacity);
+            SetPixelOpacity(q,ClampToQuantum(fill->opacity));
           if (((channel & IndexChannel) != 0) &&
               (image->colorspace == CMYKColorspace))
-            indexes[x]=ClampToQuantum(fill->index);
+            SetPixelIndex(indexes+x,ClampToQuantum(fill->index));
         }
       q++;
     }
@@ -949,7 +954,7 @@ MagickExport MagickBooleanType TransparentPaintImage(Image *image,
   GetMagickPixelPacket(image,&zero);
   image_view=AcquireCacheView(image);
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp parallel for schedule(dynamic,4) shared(progress,status)
+  #pragma omp parallel for schedule(static,4) shared(progress,status)
 #endif
   for (y=0; y < (ssize_t) image->rows; y++)
   {
@@ -1081,7 +1086,7 @@ MagickExport MagickBooleanType TransparentPaintImageChroma(Image *image,
   exception=(&image->exception);
   image_view=AcquireCacheView(image);
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp parallel for schedule(dynamic,4) shared(progress,status)
+  #pragma omp parallel for schedule(static,4) shared(progress,status)
 #endif
   for (y=0; y < (ssize_t) image->rows; y++)
   {
