@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2010 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2012 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
 
   You may not use this file except in compliance with the License.
@@ -197,6 +197,8 @@ static const char
   {
     "",
     "-verbose",
+    "-features 1 -verbose",
+    "-unique -verbose",
     (const char *) NULL
   };
 
@@ -251,16 +253,14 @@ static const struct ReferenceFormats
     { "DNG", UndefinedCompression, 0.0 },
     { "DOT", UndefinedCompression, 0.0 },
     { "DPS", UndefinedCompression, 0.0 },
-    { "DPX", UndefinedCompression, 0.0 },
+    { "DPX", UndefinedCompression, 0.003 },
     { "ERF", UndefinedCompression, 0.0 },
     { "EXR", UndefinedCompression, 0.0 },
-    { "FITS", UndefinedCompression, 0.003 },
     { "FPX", UndefinedCompression, 0.0 },
     { "FRACTAL", UndefinedCompression, 0.0 },
-    { "FTS", UndefinedCompression, 0.003 },
     { "GIF", UndefinedCompression, 0.0 },
     { "GIF87", UndefinedCompression, 0.0 },
-    { "GRAY", UndefinedCompression, 0.0 },
+    { "GRAY", UndefinedCompression, 0.003 },
     { "HTM", UndefinedCompression, 0.0 },
     { "HRZ", UndefinedCompression, 0.0 },
     { "HTML", UndefinedCompression, 0.0 },
@@ -277,12 +277,10 @@ static const struct ReferenceFormats
     { "JPG", UndefinedCompression, 0.003 },
     { "K25", UndefinedCompression, 0.0 },
     { "KDC", UndefinedCompression, 0.0 },
-    { "MAT", UndefinedCompression, 0.0 },
     { "MATTE", UndefinedCompression, 0.0 },
     { "MIFF", UndefinedCompression, 0.0 },
     { "MNG", UndefinedCompression, 0.0 },
     { "MONO", UndefinedCompression, 0.0 },
-    { "MOV", UndefinedCompression, 0.0 },
     { "MRW", UndefinedCompression, 0.0 },
     { "MTV", UndefinedCompression, 0.0 },
     { "NEF", UndefinedCompression, 0.0 },
@@ -300,7 +298,9 @@ static const struct ReferenceFormats
     { "PFM", UndefinedCompression, 0.0 },
     { "PGM", UndefinedCompression, 0.0 },
     { "PGX", UndefinedCompression, 0.0 },
+#if !defined(MAGICKCORE_HDRI_SUPPORT)
     { "PICT", UndefinedCompression, 0.003 },
+#endif
     { "PIX", UndefinedCompression, 0.0 },
     { "PJPEG", UndefinedCompression, 0.003 },
     { "PLASMA", UndefinedCompression, 0.0 },
@@ -317,7 +317,7 @@ static const struct ReferenceFormats
     { "RAS", UndefinedCompression, 0.0 },
     { "RGB", UndefinedCompression, 0.0 },
     { "RGBA", UndefinedCompression, 0.003 },
-    { "RGBO", UndefinedCompression, 0.0 },
+    { "RGBO", UndefinedCompression, 0.003 },
     { "RLA", UndefinedCompression, 0.0 },
     { "RLE", UndefinedCompression, 0.0 },
     { "SCR", UndefinedCompression, 0.0 },
@@ -351,7 +351,7 @@ static const struct ReferenceFormats
     { "XPM", UndefinedCompression, 0.0 },
     { "XPS", UndefinedCompression, 0.0 },
     { "XV", UndefinedCompression, 0.0 },
-#if !defined(__WINDOWS__)
+#if !defined(MAGICKCORE_WINDOWS_SUPPORT)
     { "XWD", UndefinedCompression, 0.0 },
 #endif
     { "YUV", UndefinedCompression, 0.0 },
@@ -418,7 +418,7 @@ static const struct ReferenceStorage
     { DoublePixel, sizeof(double) },
     { FloatPixel, sizeof(float) },
     { IntegerPixel, sizeof(unsigned int) },
-    { LongPixel, sizeof(unsigned long) },
+    { LongPixel, sizeof(size_t) },
     { ShortPixel, sizeof(unsigned short) },
     { UndefinedPixel, 0 }
   };
@@ -428,7 +428,7 @@ struct ReferenceTypes
   ImageType
     type;
 
-  unsigned long
+  size_t
     depth;
 };
 
