@@ -22,7 +22,7 @@
 %                                March 2003                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2011 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2012 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -287,7 +287,7 @@ WandExport MagickBooleanType DuplexTransferWandViewIterator(WandView *source,
   progress=0;
   exception=destination->exception;
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp parallel for schedule(static,1) shared(progress,status) num_threads(source->number_threads)
+  #pragma omp parallel for schedule(static) shared(progress,status) num_threads(source->number_threads)
 #endif
   for (y=source->extent.y; y < (ssize_t) source->extent.height; y++)
   {
@@ -329,11 +329,11 @@ WandExport MagickBooleanType DuplexTransferWandViewIterator(WandView *source,
     if (source_image->colorspace == CMYKColorspace)
       for (x=0; x < (ssize_t) source->extent.width; x++)
         PixelSetBlackQuantum(source->pixel_wands[id][x],
-          GetBlackPixelComponent(indexes+x));
+          GetPixelBlack(indexes+x));
     if (source_image->storage_class == PseudoClass)
       for (x=0; x < (ssize_t) source->extent.width; x++)
         PixelSetIndex(source->pixel_wands[id][x],
-          GetIndexPixelComponent(indexes+x));
+          GetPixelIndex(indexes+x));
     duplex_pixels=GetCacheViewVirtualPixels(duplex->view,duplex->extent.x,y,
       duplex->extent.width,1,duplex->exception);
     if (duplex_pixels == (const PixelPacket *) NULL)
@@ -347,11 +347,11 @@ WandExport MagickBooleanType DuplexTransferWandViewIterator(WandView *source,
     if (duplex_image->colorspace == CMYKColorspace)
       for (x=0; x < (ssize_t) duplex->extent.width; x++)
         PixelSetBlackQuantum(duplex->pixel_wands[id][x],
-          GetBlackPixelComponent(duplex_indexes+x));
+          GetPixelBlack(duplex_indexes+x));
     if (duplex_image->storage_class == PseudoClass)
       for (x=0; x < (ssize_t) duplex->extent.width; x++)
         PixelSetIndex(duplex->pixel_wands[id][x],
-          GetIndexPixelComponent(duplex_indexes+x));
+          GetPixelIndex(duplex_indexes+x));
     destination_pixels=GetCacheViewAuthenticPixels(destination->view,
       destination->extent.x,y,destination->extent.width,1,exception);
     if (destination_pixels == (PixelPacket *) NULL)
@@ -366,11 +366,11 @@ WandExport MagickBooleanType DuplexTransferWandViewIterator(WandView *source,
     if (destination_image->colorspace == CMYKColorspace)
       for (x=0; x < (ssize_t) destination->extent.width; x++)
         PixelSetBlackQuantum(destination->pixel_wands[id][x],
-          GetBlackPixelComponent(destination_indexes+x));
+          GetPixelBlack(destination_indexes+x));
     if (destination_image->storage_class == PseudoClass)
       for (x=0; x < (ssize_t) destination->extent.width; x++)
         PixelSetIndex(destination->pixel_wands[id][x],
-          GetIndexPixelComponent(destination_indexes+x));
+          GetPixelIndex(destination_indexes+x));
     if (transfer(source,duplex,destination,y,id,context) == MagickFalse)
       status=MagickFalse;
     for (x=0; x < (ssize_t) destination->extent.width; x++)
@@ -378,7 +378,7 @@ WandExport MagickBooleanType DuplexTransferWandViewIterator(WandView *source,
         destination_pixels+x);
     if (destination_image->colorspace == CMYKColorspace)
       for (x=0; x < (ssize_t) destination->extent.width; x++)
-        SetBlackPixelComponent(destination_indexes+x,PixelGetBlackQuantum(
+        SetPixelBlack(destination_indexes+x,PixelGetBlackQuantum(
           destination->pixel_wands[id][x]));
     sync=SyncCacheViewAuthenticPixels(destination->view,exception);
     if (sync == MagickFalse)
@@ -393,7 +393,7 @@ WandExport MagickBooleanType DuplexTransferWandViewIterator(WandView *source,
           proceed;
 
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp critical (MagickWand_DuplexTransferWandViewIterator)
+       #pragma omp critical (MagickWand_DuplexTransferWandViewIterator)
 #endif
         proceed=SetImageProgress(source_image,source->description,progress++,
           source->extent.height);
@@ -558,7 +558,7 @@ WandExport MagickBooleanType GetWandViewIterator(WandView *source,
   status=MagickTrue;
   progress=0;
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp parallel for schedule(static,1) shared(progress,status) num_threads(source->number_threads)
+  #pragma omp parallel for schedule(static) shared(progress,status) num_threads(source->number_threads)
 #endif
   for (y=source->extent.y; y < (ssize_t) source->extent.height; y++)
   {
@@ -589,11 +589,11 @@ WandExport MagickBooleanType GetWandViewIterator(WandView *source,
     if (source_image->colorspace == CMYKColorspace)
       for (x=0; x < (ssize_t) source->extent.width; x++)
         PixelSetBlackQuantum(source->pixel_wands[id][x],
-          GetBlackPixelComponent(indexes+x));
+          GetPixelBlack(indexes+x));
     if (source_image->storage_class == PseudoClass)
       for (x=0; x < (ssize_t) source->extent.width; x++)
         PixelSetIndex(source->pixel_wands[id][x],
-          GetIndexPixelComponent(indexes+x));
+          GetPixelIndex(indexes+x));
     if (get(source,y,id,context) == MagickFalse)
       status=MagickFalse;
     if (source_image->progress_monitor != (MagickProgressMonitor) NULL)
@@ -602,7 +602,7 @@ WandExport MagickBooleanType GetWandViewIterator(WandView *source,
           proceed;
 
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp critical (MagickWand_GetWandViewIterator)
+        #pragma omp critical (MagickWand_GetWandViewIterator)
 #endif
         proceed=SetImageProgress(source_image,source->description,progress++,
           source->extent.height);
@@ -958,7 +958,7 @@ WandExport MagickBooleanType SetWandViewIterator(WandView *destination,
   progress=0;
   exception=destination->exception;
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp parallel for schedule(static,1) shared(progress,status) num_threads(destination->number_threads)
+  #pragma omp parallel for schedule(static) shared(progress,status) num_threads(destination->number_threads)
 #endif
   for (y=destination->extent.y; y < (ssize_t) destination->extent.height; y++)
   {
@@ -995,7 +995,7 @@ WandExport MagickBooleanType SetWandViewIterator(WandView *destination,
       PixelGetQuantumColor(destination->pixel_wands[id][x],pixels+x);
     if (destination_image->colorspace == CMYKColorspace)
       for (x=0; x < (ssize_t) destination->extent.width; x++)
-        SetBlackPixelComponent(indexes+x,PixelGetBlackQuantum(
+        SetPixelBlack(indexes+x,PixelGetBlackQuantum(
           destination->pixel_wands[id][x]));
     sync=SyncCacheViewAuthenticPixels(destination->view,exception);
     if (sync == MagickFalse)
@@ -1010,7 +1010,7 @@ WandExport MagickBooleanType SetWandViewIterator(WandView *destination,
           proceed;
 
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp critical (MagickWand_SetWandViewIterator)
+        #pragma omp critical (MagickWand_SetWandViewIterator)
 #endif
         proceed=SetImageProgress(destination_image,destination->description,
           progress++,destination->extent.height);
@@ -1135,7 +1135,7 @@ WandExport MagickBooleanType TransferWandViewIterator(WandView *source,
   progress=0;
   exception=destination->exception;
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp parallel for schedule(static,1) shared(progress,status) num_threads(source->number_threads)
+  #pragma omp parallel for schedule(static) shared(progress,status) num_threads(source->number_threads)
 #endif
   for (y=source->extent.y; y < (ssize_t) source->extent.height; y++)
   {
@@ -1175,11 +1175,11 @@ WandExport MagickBooleanType TransferWandViewIterator(WandView *source,
     if (source_image->colorspace == CMYKColorspace)
       for (x=0; x < (ssize_t) source->extent.width; x++)
         PixelSetBlackQuantum(source->pixel_wands[id][x],
-          GetBlackPixelComponent(indexes+x));
+          GetPixelBlack(indexes+x));
     if (source_image->storage_class == PseudoClass)
       for (x=0; x < (ssize_t) source->extent.width; x++)
         PixelSetIndex(source->pixel_wands[id][x],
-          GetIndexPixelComponent(indexes+x));
+          GetPixelIndex(indexes+x));
     destination_pixels=GetCacheViewAuthenticPixels(destination->view,
       destination->extent.x,y,destination->extent.width,1,exception);
     if (destination_pixels == (PixelPacket *) NULL)
@@ -1193,11 +1193,11 @@ WandExport MagickBooleanType TransferWandViewIterator(WandView *source,
     if (destination_image->colorspace == CMYKColorspace)
       for (x=0; x < (ssize_t) destination->extent.width; x++)
         PixelSetBlackQuantum(destination->pixel_wands[id][x],
-          GetBlackPixelComponent(indexes+x));
+          GetPixelBlack(indexes+x));
     if (destination_image->storage_class == PseudoClass)
       for (x=0; x < (ssize_t) destination->extent.width; x++)
         PixelSetIndex(destination->pixel_wands[id][x],
-          GetIndexPixelComponent(indexes+x));
+          GetPixelIndex(indexes+x));
     if (transfer(source,destination,y,id,context) == MagickFalse)
       status=MagickFalse;
     for (x=0; x < (ssize_t) destination->extent.width; x++)
@@ -1205,7 +1205,7 @@ WandExport MagickBooleanType TransferWandViewIterator(WandView *source,
         destination_pixels+x);
     if (destination_image->colorspace == CMYKColorspace)
       for (x=0; x < (ssize_t) destination->extent.width; x++)
-        SetBlackPixelComponent(destination_indexes+x,PixelGetBlackQuantum(
+        SetPixelBlack(destination_indexes+x,PixelGetBlackQuantum(
           destination->pixel_wands[id][x]));
     sync=SyncCacheViewAuthenticPixels(destination->view,exception);
     if (sync == MagickFalse)
@@ -1220,7 +1220,7 @@ WandExport MagickBooleanType TransferWandViewIterator(WandView *source,
           proceed;
 
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp critical (MagickWand_TransferWandViewIterator)
+        #pragma omp critical (MagickWand_TransferWandViewIterator)
 #endif
         proceed=SetImageProgress(source_image,source->description,progress++,
           source->extent.height);
@@ -1303,7 +1303,7 @@ WandExport MagickBooleanType UpdateWandViewIterator(WandView *source,
   progress=0;
   exception=source->exception;
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp parallel for schedule(static,1) shared(progress,status) num_threads(source->number_threads)
+  #pragma omp parallel for schedule(static) shared(progress,status) num_threads(source->number_threads)
 #endif
   for (y=source->extent.y; y < (ssize_t) source->extent.height; y++)
   {
@@ -1336,14 +1336,14 @@ WandExport MagickBooleanType UpdateWandViewIterator(WandView *source,
     if (source_image->colorspace == CMYKColorspace)
       for (x=0; x < (ssize_t) source->extent.width; x++)
         PixelSetBlackQuantum(source->pixel_wands[id][x],
-          GetBlackPixelComponent(indexes+x));
+          GetPixelBlack(indexes+x));
     if (update(source,y,id,context) == MagickFalse)
       status=MagickFalse;
     for (x=0; x < (ssize_t) source->extent.width; x++)
       PixelGetQuantumColor(source->pixel_wands[id][x],pixels+x);
     if (source_image->colorspace == CMYKColorspace)
       for (x=0; x < (ssize_t) source->extent.width; x++)
-        SetBlackPixelComponent(indexes+x,PixelGetBlackQuantum(
+        SetPixelBlack(indexes+x,PixelGetBlackQuantum(
           source->pixel_wands[id][x]));
     if (SyncCacheViewAuthenticPixels(source->view,exception) == MagickFalse)
       {
@@ -1356,7 +1356,7 @@ WandExport MagickBooleanType UpdateWandViewIterator(WandView *source,
           proceed;
 
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp critical (MagickWand_UpdateWandViewIterator)
+        #pragma omp critical (MagickWand_UpdateWandViewIterator)
 #endif
         proceed=SetImageProgress(source_image,source->description,progress++,
           source->extent.height);
